==============================
 Querying dataset information
==============================

.. automodule:: gwosc.datasets

.. rubric:: Functions
   :class: h2

.. automodsumm:: gwosc.datasets
   :functions-only:
   :toctree: reference/
